# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: storage.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rstorage.proto\x12\x07storage\x1a\x0evalidate.proto\"%\n\x07Storage\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\xa8\x01\n\x06Object\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04type\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prefix\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04size\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x19\n\x0clastmodified\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_typeB\t\n\x07_prefixB\x07\n\x05_sizeB\x0f\n\r_lastmodified\"k\n\x14StorageResponseError\x12(\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x15.storage.StorageErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"i\n\x13ObjectResponseError\x12\'\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x14.storage.ObjectErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"\x80\x01\n%ObjectStorageCredentialsResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.storage.CredentialsErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"y\n\x12StorageListRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"u\n\x13StorageListResponse\x12!\n\x07storage\x18\x01 \x03(\x0b\x32\x10.storage.Storage\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"J\n\x14StorageCreateRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"\x88\x01\n\x15StorageCreateResponse\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x01\x88\x01\x01\x42\n\n\x08_storageB\x08\n\x06_error\"J\n\x14StorageDeleteRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"T\n\x15StorageDeleteResponse\x12\x31\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x7f\n\x18StorageListObjectRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"y\n\x19StorageListObjectResponse\x12\x1f\n\x06object\x18\x01 \x03(\x0b\x32\x0f.storage.Object\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.storage.StorageResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"z\n\x13ObjectCreateRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"R\n\x14ObjectCreateResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"x\n\x11ObjectListRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"q\n\x12ObjectListResponse\x12\x1f\n\x06object\x18\x01 \x03(\x0b\x32\x0f.storage.Object\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"w\n\x10ObjectGetRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x12$\n\x06object\x18\x02 \x01(\x0b\x32\x0f.storage.ObjectH\x01\x88\x01\x01\x42\n\n\x08_storageB\t\n\x07_object\"\x80\x01\n\x11ObjectGetResponse\x12$\n\x06object\x18\x01 \x01(\x0b\x32\x0f.storage.ObjectH\x00\x88\x01\x01\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x01\x88\x01\x01\x42\t\n\x07_objectB\x08\n\x06_error\"F\n\x13ObjectDeleteRequest\x12$\n\x06object\x18\x01 \x01(\x0b\x32\x0f.storage.ObjectH\x00\x88\x01\x01\x42\t\n\x07_object\"R\n\x14ObjectDeleteResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.storage.ObjectResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x9e\x02\n\x1aObjectStorageS3Credentials\x12\x19\n\x0c\x65ndpoint_url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bregion_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\raccess_key_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nsecret_key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1a\n\rsession_token\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x17\n\nexpiration\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x0f\n\r_endpoint_urlB\x0e\n\x0c_region_nameB\x10\n\x0e_access_key_idB\r\n\x0b_secret_keyB\x10\n\x0e_session_tokenB\r\n\x0b_expiration\"\xa1\x01\n\x1dObjectStorageAzureCredentials\x12\x19\n\x0c\x65ndpoint_url\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\raccess_key_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\nsecret_key\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0f\n\r_endpoint_urlB\x10\n\x0e_access_key_idB\r\n\x0b_secret_key\"K\n\x18ObjectStorageCredentials\x12/\n\x02s3\x18\x01 \x01(\x0b\x32#.storage.ObjectStorageS3Credentials\"U\n\x1fObjectStorageCredentialsRequest\x12&\n\x07storage\x18\x01 \x01(\x0b\x32\x10.storage.StorageH\x00\x88\x01\x01\x42\n\n\x08_storage\"\xbd\x01\n ObjectStorageCredentialsResponse\x12;\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32!.storage.ObjectStorageCredentialsH\x00\x88\x01\x01\x12\x42\n\x05\x65rror\x18\x02 \x01(\x0b\x32..storage.ObjectStorageCredentialsResponseErrorH\x01\x88\x01\x01\x42\x0e\n\x0c_credentialsB\x08\n\x06_error*r\n\x0cStorageError\x12\x14\n\x10STORAGE_NO_ERROR\x10\x00\x12\x19\n\x15STORAGE_ALREADY_EXIST\x10\x01\x12\x15\n\x11STORAGE_NOT_FOUND\x10\x02\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07*\x83\x01\n\x0bObjectError\x12\x13\n\x0fOBJECT_NO_ERROR\x10\x00\x12\x18\n\x14OBJECT_ALREADY_EXIST\x10\x01\x12\x15\n\x11OBJECT_SIZE_ERROR\x10\x02\x12\x14\n\x10OBJECT_NOT_FOUND\x10\x03\x12\x18\n\x14OBJECT_DIR_NOT_EMPTY\x10\x04*,\n\x10\x43redentialsError\x12\x18\n\x14\x43REDENTIALS_NO_ERROR\x10\x00\x42\x30Z.github.com/jupyter-naas/naas-models/go/storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'storage_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/storage'
  _globals['_STORAGEERROR']._serialized_start=3132
  _globals['_STORAGEERROR']._serialized_end=3246
  _globals['_OBJECTERROR']._serialized_start=3249
  _globals['_OBJECTERROR']._serialized_end=3380
  _globals['_CREDENTIALSERROR']._serialized_start=3382
  _globals['_CREDENTIALSERROR']._serialized_end=3426
  _globals['_STORAGE']._serialized_start=42
  _globals['_STORAGE']._serialized_end=79
  _globals['_OBJECT']._serialized_start=82
  _globals['_OBJECT']._serialized_end=250
  _globals['_STORAGERESPONSEERROR']._serialized_start=252
  _globals['_STORAGERESPONSEERROR']._serialized_end=359
  _globals['_OBJECTRESPONSEERROR']._serialized_start=361
  _globals['_OBJECTRESPONSEERROR']._serialized_end=466
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSEERROR']._serialized_start=469
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSEERROR']._serialized_end=597
  _globals['_STORAGELISTREQUEST']._serialized_start=599
  _globals['_STORAGELISTREQUEST']._serialized_end=720
  _globals['_STORAGELISTRESPONSE']._serialized_start=722
  _globals['_STORAGELISTRESPONSE']._serialized_end=839
  _globals['_STORAGECREATEREQUEST']._serialized_start=841
  _globals['_STORAGECREATEREQUEST']._serialized_end=915
  _globals['_STORAGECREATERESPONSE']._serialized_start=918
  _globals['_STORAGECREATERESPONSE']._serialized_end=1054
  _globals['_STORAGEDELETEREQUEST']._serialized_start=1056
  _globals['_STORAGEDELETEREQUEST']._serialized_end=1130
  _globals['_STORAGEDELETERESPONSE']._serialized_start=1132
  _globals['_STORAGEDELETERESPONSE']._serialized_end=1216
  _globals['_STORAGELISTOBJECTREQUEST']._serialized_start=1218
  _globals['_STORAGELISTOBJECTREQUEST']._serialized_end=1345
  _globals['_STORAGELISTOBJECTRESPONSE']._serialized_start=1347
  _globals['_STORAGELISTOBJECTRESPONSE']._serialized_end=1468
  _globals['_OBJECTCREATEREQUEST']._serialized_start=1470
  _globals['_OBJECTCREATEREQUEST']._serialized_end=1592
  _globals['_OBJECTCREATERESPONSE']._serialized_start=1594
  _globals['_OBJECTCREATERESPONSE']._serialized_end=1676
  _globals['_OBJECTLISTREQUEST']._serialized_start=1678
  _globals['_OBJECTLISTREQUEST']._serialized_end=1798
  _globals['_OBJECTLISTRESPONSE']._serialized_start=1800
  _globals['_OBJECTLISTRESPONSE']._serialized_end=1913
  _globals['_OBJECTGETREQUEST']._serialized_start=1915
  _globals['_OBJECTGETREQUEST']._serialized_end=2034
  _globals['_OBJECTGETRESPONSE']._serialized_start=2037
  _globals['_OBJECTGETRESPONSE']._serialized_end=2165
  _globals['_OBJECTDELETEREQUEST']._serialized_start=2167
  _globals['_OBJECTDELETEREQUEST']._serialized_end=2237
  _globals['_OBJECTDELETERESPONSE']._serialized_start=2239
  _globals['_OBJECTDELETERESPONSE']._serialized_end=2321
  _globals['_OBJECTSTORAGES3CREDENTIALS']._serialized_start=2324
  _globals['_OBJECTSTORAGES3CREDENTIALS']._serialized_end=2610
  _globals['_OBJECTSTORAGEAZURECREDENTIALS']._serialized_start=2613
  _globals['_OBJECTSTORAGEAZURECREDENTIALS']._serialized_end=2774
  _globals['_OBJECTSTORAGECREDENTIALS']._serialized_start=2776
  _globals['_OBJECTSTORAGECREDENTIALS']._serialized_end=2851
  _globals['_OBJECTSTORAGECREDENTIALSREQUEST']._serialized_start=2853
  _globals['_OBJECTSTORAGECREDENTIALSREQUEST']._serialized_end=2938
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSE']._serialized_start=2941
  _globals['_OBJECTSTORAGECREDENTIALSRESPONSE']._serialized_end=3130
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from naas_models.pydantic.common_p2p import FieldMask
from enum import IntEnum
from naas_models.pydantic.errors_p2p import ErrorResponse
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
from uuid import UUID
import typing

class MessageType(IntEnum):
    UNDEFINED = 0
    SYSTEM = 1
    AI = 2
    HUMAN = 3
    TOOL_USAGE = 5
    TOOL_ANSWER = 6


class CompletionStatus(IntEnum):
    COMPLETED = 0
    FAILED = 1
    TIMEOUT = 2

class Message(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    version: typing.Optional[int] = Field(default=0) 
    created_at: typing.Optional[str] = Field(default="") 
    chat_id: typing.Optional[int] = Field(default=0) 
    from_user: typing.Optional[bool] = Field(default=False) 
    message: typing.Optional[str] = Field(default="") 
    message_type: typing.Optional[str] = Field(default="") 
    message_language: typing.Optional[str] = Field(default="") 
    model_id: typing.Optional[str] = Field(default="") 
    type: typing.Optional[MessageType] = Field(default=0) 
    metadata: typing.Optional[str] = Field(default="") 
    deleted_at: typing.Optional[str] = Field(default="") 
    selected: typing.Optional[bool] = Field(default=False) 
    archived_at: typing.Optional[str] = Field(default="") 

class MessageUpdate(BaseModel):
    message: typing.Optional[str] = Field(default="") 
    message_type: typing.Optional[str] = Field(default="") 
    message_language: typing.Optional[str] = Field(default="") 
    metadata: typing.Optional[str] = Field(default="") 
    selected: typing.Optional[bool] = Field(default=False) 
    archived_at: typing.Optional[str] = Field(default="") 
    field_mask: typing.Optional[FieldMask] = Field(default=None) 

class Messages(BaseModel):
    messages: typing.List[Message] = Field(default_factory=list) 

class MessageDeletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    version: typing.Optional[int] = Field(default=0) 

class MessageDeletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class MessageRating(BaseModel):
    message_id: typing.Optional[int] = Field(default=0) 
    user_id: typing.Optional[str] = Field(default="") 
    message_version: typing.Optional[int] = Field(default=0) 
    created_at: typing.Optional[str] = Field(default="") 
    rating: typing.Optional[str] = Field(default="", pattern="^(LIKE|DISLIKE)$") 

class MessageRatingCreationRequest(BaseModel):
    message_id: typing.Optional[int] = Field(default=0) 
    message_version: typing.Optional[int] = Field(default=0) 
    rating: typing.Optional[str] = Field(default="", pattern="^(LIKE|DISLIKE)$") 

class MessageRatingCreationResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    message_rating: typing.Optional[MessageRating] = Field(default=None) 

class Chat(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    created_at: typing.Optional[str] = Field(default="") 
    user_id: typing.Optional[str] = Field(default="") 
    name: typing.Optional[str] = Field(default="") 
    deleted_at: typing.Optional[str] = Field(default="") 
    is_group: typing.Optional[bool] = Field(default=False) 
    is_personal_assistant: typing.Optional[bool] = Field(default=False) 
    starred_at: typing.Optional[str] = Field(default="") 

class ChatUpdate(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    is_group: typing.Optional[bool] = Field(default=False) 
    is_personal_assistant: typing.Optional[bool] = Field(default=False) 
    starred_at: typing.Optional[str] = Field(default="") 
    field_mask: typing.Optional[FieldMask] = Field(default=None) 

class ChatMessages(BaseModel):
    messages: typing.Dict[int, Messages] = Field(default_factory=dict) 

class ChatCreationRequest(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    is_personal_assistant: typing.Optional[bool] = Field(default=False) 

class ChatCreationResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default=None) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatGetRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 

class ChatGetResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default=None) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatMessageGetRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 

class ChatMessageGetResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    messages: typing.Optional[ChatMessages] = Field(default=None) 

class ChatDeletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 

class ChatDeletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatUpdateRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    chat_update: typing.Optional[ChatUpdate] = Field(default=None) 

class ChatUpdateResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default=None) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0) 
    page_number: typing.Optional[int] = Field(default=0) 

class ChatListResponse(BaseModel):
    chat: typing.List[Chat] = Field(default_factory=list) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatStarRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    star: typing.Optional[bool] = Field(default=False) 

class ChatStarResponse(BaseModel):
    chat: typing.Optional[Chat] = Field(default=None) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatArchiveRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 

class ChatArchiveResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class CompletionResponse(BaseModel):
    messages: typing.List[Message] = Field(default_factory=list) 
    input_tokens: typing.Optional[int] = Field(default=0) 
    output_tokens: typing.Optional[int] = Field(default=0) 
    image_resolution: typing.Optional[str] = Field(default="") 
    image_steps: typing.Optional[int] = Field(default=0) 
    status: typing.Optional[CompletionStatus] = Field(default=0) 

class BasePayload(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    url: typing.Optional[str] = Field(default="") 
    prompt: typing.Optional[str] = Field(default="") 

class ChatCompletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 
    model_id: typing.Optional[str] = Field(default="") 
    payload: typing.Optional[str] = Field(default="") 
    plugin_id: typing.Optional[UUID] = Field(default="") 

class ChatStopCompletionRequest(BaseModel):
    id: typing.Optional[int] = Field(default=0) 

class ChatStopCompletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 

class ChatCompletionResponse(BaseModel):
    completion: typing.Optional[CompletionResponse] = Field(default=None) 
    error: typing.Optional[ErrorResponse] = Field(default=None) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: errors.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65rrors.proto\x12\x06\x65rrors\x1a\x0evalidate.proto\"\\\n\rErrorResponse\x12 \n\x04\x63ode\x18\x01 \x01(\x0e\x32\r.errors.ErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message*\xcc\x06\n\x05\x45rror\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xc7\x01\x12\x17\n\x12IAM_USER_NOT_FOUND\x10\xc8\x01\x12\x1c\n\x17IAM_USER_NOT_AUTHORIZED\x10\xc9\x01\x12\x1f\n\x1aIAM_API_KEY_ALREADY_EXISTS\x10\xca\x01\x12\x18\n\x13WORKSPACE_NOT_FOUND\x10\xac\x02\x12\"\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\xae\x02\x12\x1d\n\x18WORKSPACE_USER_NOT_FOUND\x10\xaf\x02\x12\"\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\xb0\x02\x12\x33\n.WORKSPACE_USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\xb1\x02\x12\x1f\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\xb2\x02\x12\x1d\n\x18WORKSPACE_INVITE_INVALID\x10\xb3\x02\x12\x32\n-WORKSPACE_CANNOT_INVITE_TO_PERSONAL_WORKSPACE\x10\xb4\x02\x12\x1f\n\x1a\x43REDITS_USER_HAS_NO_PARENT\x10\x90\x03\x12\x1b\n\x16\x43REDITS_OUT_OF_CREDITS\x10\x91\x03\x12\x17\n\x12ONTOLOGY_NOT_FOUND\x10\xf4\x03\x12\x13\n\x0e\x43HAT_NOT_FOUND\x10\xd8\x04\x12\x18\n\x13\x43HAT_NOT_AUTHORIZED\x10\xd9\x04\x12+\n&CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXIST\x10\xda\x04\x12!\n\x1c\x43HAT_CONTEXT_LENGTH_EXCEEDED\x10\xdb\x04\x12 \n\x1b\x43HAT_MESSAGE_ALREADY_EXISTS\x10\xdc\x04\x12\x1b\n\x16\x43HAT_MESSAGE_NOT_FOUND\x10\xdd\x04\x12\x1f\n\x1a\x43HAT_INTERNAL_SERVER_ERROR\x10\xbb\x05\x12\x16\n\x11\x41IMODEL_NOT_FOUND\x10\xbc\x05\x12\x14\n\x0f\x41SSET_NOT_FOUND\x10\xa0\x06\x12\x19\n\x14\x41SSET_ALREADY_EXISTS\x10\xa1\x06\x12\x18\n\x13\x41SSET_REQUEST_ERROR\x10\xa2\x06\x42/Z-github.com/jupyter-naas/naas-models/go/errorsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'errors_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z-github.com/jupyter-naas/naas-models/go/errors'
  _globals['_ERROR']._serialized_start=135
  _globals['_ERROR']._serialized_end=979
  _globals['_ERRORRESPONSE']._serialized_start=40
  _globals['_ERRORRESPONSE']._serialized_end=132
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
import typing

class SecretError(IntEnum):
    SECRET_NO_ERROR = 0
    SECRET_ALREADY_EXISTS = 1
    SECRET_NOT_FOUND = 2
    SECRET_MARKED_FOR_DELETION = 3

class Secret(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    value: typing.Optional[str] = Field(default="") 

class SecretResponseError(BaseModel):
    error: typing.Optional[SecretError] = Field(default=0) 
    message: typing.Optional[str] = Field(default="") 

class SecretCreateRequest(BaseModel):
    secret: typing.Optional[Secret] = Field(default=None) 

class SecretCreateResponse(BaseModel):
    error: typing.Optional[SecretResponseError] = Field(default=None) 

class SecretGetRequest(BaseModel):
    name: typing.Optional[str] = Field(default="") 

class SecretGetResponse(BaseModel):
    secret: typing.Optional[Secret] = Field(default=None) 
    error: typing.Optional[SecretResponseError] = Field(default=None) 

class SecretDeleteRequest(BaseModel):
    name: typing.Optional[str] = Field(default="") 

class SecretDeleteResponse(BaseModel):
    error: typing.Optional[SecretResponseError] = Field(default=None) 

class SecretListRequest(BaseModel):
    page_size: typing.Optional[int] = Field(default=0) 
    page_number: typing.Optional[int] = Field(default=0) 

class SecretListResponse(BaseModel):
    secrets: typing.List[Secret] = Field(default_factory=list) 
    error: typing.Optional[SecretResponseError] = Field(default=None) 

class SecretBulkCreateRequest(BaseModel):
    secrets: typing.List[Secret] = Field(default_factory=list) 

class SecretBulkCreateResponse(BaseModel):
    error: typing.List[SecretResponseError] = Field(default_factory=list) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csecret.proto\x12\x07secrets\x1a\x0evalidate.proto\"B\n\x06Secret\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"k\n\x13SecretResponseError\x12(\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x14.secrets.SecretErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\n\n\x08_message\"F\n\x13SecretCreateRequest\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x42\t\n\x07_secret\"R\n\x14SecretCreateResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\".\n\x10SecretGetRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x80\x01\n\x11SecretGetResponse\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x01\x88\x01\x01\x42\t\n\x07_secretB\x08\n\x06_error\"1\n\x13SecretDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x14SecretDeleteResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"c\n\x11SecretListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"r\n\x12SecretListResponse\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\";\n\x17SecretBulkCreateRequest\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\"G\n\x18SecretBulkCreateResponse\x12+\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x1c.secrets.SecretResponseError*s\n\x0bSecretError\x12\x13\n\x0fSECRET_NO_ERROR\x10\x00\x12\x19\n\x15SECRET_ALREADY_EXISTS\x10\x01\x12\x14\n\x10SECRET_NOT_FOUND\x10\x02\x12\x1e\n\x1aSECRET_MARKED_FOR_DELETION\x10\x03\x42\x30Z.github.com/jupyter-naas/naas-models/go/secretsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'secret_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/secrets'
  _globals['_SECRETERROR']._serialized_start=1039
  _globals['_SECRETERROR']._serialized_end=1154
  _globals['_SECRET']._serialized_start=41
  _globals['_SECRET']._serialized_end=107
  _globals['_SECRETRESPONSEERROR']._serialized_start=109
  _globals['_SECRETRESPONSEERROR']._serialized_end=216
  _globals['_SECRETCREATEREQUEST']._serialized_start=218
  _globals['_SECRETCREATEREQUEST']._serialized_end=288
  _globals['_SECRETCREATERESPONSE']._serialized_start=290
  _globals['_SECRETCREATERESPONSE']._serialized_end=372
  _globals['_SECRETGETREQUEST']._serialized_start=374
  _globals['_SECRETGETREQUEST']._serialized_end=420
  _globals['_SECRETGETRESPONSE']._serialized_start=423
  _globals['_SECRETGETRESPONSE']._serialized_end=551
  _globals['_SECRETDELETEREQUEST']._serialized_start=553
  _globals['_SECRETDELETEREQUEST']._serialized_end=602
  _globals['_SECRETDELETERESPONSE']._serialized_start=604
  _globals['_SECRETDELETERESPONSE']._serialized_end=686
  _globals['_SECRETLISTREQUEST']._serialized_start=688
  _globals['_SECRETLISTREQUEST']._serialized_end=787
  _globals['_SECRETLISTRESPONSE']._serialized_start=789
  _globals['_SECRETLISTRESPONSE']._serialized_end=903
  _globals['_SECRETBULKCREATEREQUEST']._serialized_start=905
  _globals['_SECRETBULKCREATEREQUEST']._serialized_end=964
  _globals['_SECRETBULKCREATERESPONSE']._serialized_start=966
  _globals['_SECRETBULKCREATERESPONSE']._serialized_end=1037
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ontology.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2
import p2p_validate_pb2 as p2p__validate__pb2
import errors_pb2 as errors__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eontology.proto\x12\x08ontology\x1a\x0evalidate.proto\x1a\x12p2p_validate.proto\x1a\x0c\x65rrors.proto\x1a\x0c\x63ommon.proto\"\xd2\x02\n\x08Ontology\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06source\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08logo_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x12\n\x05level\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tis_public\x18\t \x01(\x08H\x07\x88\x01\x01\x42\x0f\n\r_workspace_idB\x08\n\x06_labelB\t\n\x07_sourceB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\xb9\x02\n\x0fOntologySummary\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08logo_url\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x12\n\x05level\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tis_public\x18\x08 \x01(\x08H\x06\x88\x01\x01\x42\x0f\n\r_workspace_idB\x08\n\x06_labelB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\xbc\x02\n\x10OntologyCreation\x12&\n\x0cworkspace_id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12!\n\x05label\x18\x02 \x01(\tB\x12\xfa\x42\x07r\x05\x10\x01\x18\xff\x01\x8a\x43\x05r\x03\x98\x02\x01\x12\x1f\n\x06source\x18\x03 \x01(\tB\x0f\xfa\x42\x04r\x02\x10\x01\x8a\x43\x05r\x03\x98\x02\x01\x12\x19\n\x0c\x64ownload_url\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08logo_url\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x12\n\x05level\x18\x07 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tis_public\x18\x08 \x01(\x08H\x04\x88\x01\x01\x42\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\x87\x03\n\x0eOntologyUpdate\x12\x1c\n\x02id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x12\n\x05label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06source\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x64ownload_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08logo_url\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x12\n\x05level\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tis_public\x18\t \x01(\x08H\x07\x88\x01\x01\x12%\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskB\x0f\n\r_workspace_idB\x08\n\x06_labelB\t\n\x07_sourceB\x0f\n\r_download_urlB\x0e\n\x0c_descriptionB\x0b\n\t_logo_urlB\x08\n\x06_levelB\x0c\n\n_is_public\"\x89\x01\n\x13OntologyListRequest\x12&\n\x0cworkspace_id\x18\x01 \x01(\tB\x10\xfa\x42\x05r\x03\xb0\x01\x01\x8a\x43\x05r\x03\x98\x02\x01\x12$\n\tpage_size\x18\x02 \x01(\x05\x42\x11\xfa\x42\x06\x1a\x04\x18\x64(\x01\x8a\x43\x05\x1a\x03\xa8\x01\x01\x12$\n\x0bpage_number\x18\x03 \x01(\x05\x42\x0f\xfa\x42\x04\x1a\x02(\x00\x8a\x43\x05\x1a\x03\xa8\x01\x01\"z\n\x14OntologyListResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12-\n\nontologies\x18\x02 \x03(\x0b\x32\x19.ontology.OntologySummaryB\x08\n\x06_error\"`\n\x12OntologyGetRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x82\x01\n\x13OntologyGetResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"G\n\x17OntologyCreationRequest\x12,\n\x08ontology\x18\x01 \x01(\x0b\x32\x1a.ontology.OntologyCreation\"\x87\x01\n\x18OntologyCreationResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"C\n\x15OntologyUpdateRequest\x12*\n\x08ontology\x18\x01 \x01(\x0b\x32\x18.ontology.OntologyUpdate\"\x85\x01\n\x16OntologyUpdateResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08ontology\x18\x02 \x01(\x0b\x32\x12.ontology.OntologyH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_ontology\"O\n\x17OntologyDeletionRequest\x12\x14\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\x12\x1e\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01\"O\n\x18OntologyDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error2\x95\x03\n\x0fOntologyService\x12G\n\x04List\x12\x1d.ontology.OntologyListRequest\x1a\x1e.ontology.OntologyListResponse\"\x00\x12\x44\n\x03Get\x12\x1c.ontology.OntologyGetRequest\x1a\x1d.ontology.OntologyGetResponse\"\x00\x12Q\n\x06\x43reate\x12!.ontology.OntologyCreationRequest\x1a\".ontology.OntologyCreationResponse\"\x00\x12M\n\x06Update\x12\x1f.ontology.OntologyUpdateRequest\x1a .ontology.OntologyUpdateResponse\"\x00\x12Q\n\x06\x44\x65lete\x12!.ontology.OntologyDeletionRequest\x1a\".ontology.OntologyDeletionResponse\"\x00\x42\x31Z/github.com/jupyter-naas/naas-models/go/ontologyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ontology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z/github.com/jupyter-naas/naas-models/go/ontology'
  _globals['_ONTOLOGY'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGY'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGY'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGY'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYSUMMARY'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['label']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['label']._serialized_options = b'\372B\007r\005\020\001\030\377\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYCREATION'].fields_by_name['source']._loaded_options = None
  _globals['_ONTOLOGYCREATION'].fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYUPDATE'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYUPDATE'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYUPDATE'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYUPDATE'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001\212C\005r\003\230\002\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_size']._serialized_options = b'\372B\006\032\004\030d(\001\212C\005\032\003\250\001\001'
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_number']._loaded_options = None
  _globals['_ONTOLOGYLISTREQUEST'].fields_by_name['page_number']._serialized_options = b'\372B\004\032\002(\000\212C\005\032\003\250\001\001'
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYGETREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['id']._loaded_options = None
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['workspace_id']._loaded_options = None
  _globals['_ONTOLOGYDELETIONREQUEST'].fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_ONTOLOGY']._serialized_start=93
  _globals['_ONTOLOGY']._serialized_end=431
  _globals['_ONTOLOGYSUMMARY']._serialized_start=434
  _globals['_ONTOLOGYSUMMARY']._serialized_end=747
  _globals['_ONTOLOGYCREATION']._serialized_start=750
  _globals['_ONTOLOGYCREATION']._serialized_end=1066
  _globals['_ONTOLOGYUPDATE']._serialized_start=1069
  _globals['_ONTOLOGYUPDATE']._serialized_end=1460
  _globals['_ONTOLOGYLISTREQUEST']._serialized_start=1463
  _globals['_ONTOLOGYLISTREQUEST']._serialized_end=1600
  _globals['_ONTOLOGYLISTRESPONSE']._serialized_start=1602
  _globals['_ONTOLOGYLISTRESPONSE']._serialized_end=1724
  _globals['_ONTOLOGYGETREQUEST']._serialized_start=1726
  _globals['_ONTOLOGYGETREQUEST']._serialized_end=1822
  _globals['_ONTOLOGYGETRESPONSE']._serialized_start=1825
  _globals['_ONTOLOGYGETRESPONSE']._serialized_end=1955
  _globals['_ONTOLOGYCREATIONREQUEST']._serialized_start=1957
  _globals['_ONTOLOGYCREATIONREQUEST']._serialized_end=2028
  _globals['_ONTOLOGYCREATIONRESPONSE']._serialized_start=2031
  _globals['_ONTOLOGYCREATIONRESPONSE']._serialized_end=2166
  _globals['_ONTOLOGYUPDATEREQUEST']._serialized_start=2168
  _globals['_ONTOLOGYUPDATEREQUEST']._serialized_end=2235
  _globals['_ONTOLOGYUPDATERESPONSE']._serialized_start=2238
  _globals['_ONTOLOGYUPDATERESPONSE']._serialized_end=2371
  _globals['_ONTOLOGYDELETIONREQUEST']._serialized_start=2373
  _globals['_ONTOLOGYDELETIONREQUEST']._serialized_end=2452
  _globals['_ONTOLOGYDELETIONRESPONSE']._serialized_start=2454
  _globals['_ONTOLOGYDELETIONRESPONSE']._serialized_end=2533
  _globals['_ONTOLOGYSERVICE']._serialized_start=2536
  _globals['_ONTOLOGYSERVICE']._serialized_end=2941
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from naas_models.pydantic.errors_p2p import ErrorResponse
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import Field
from pydantic import model_validator
from pydantic.networks import EmailStr
from uuid import UUID
import typing


class TokenData(BaseModel):
    user_id: typing.Optional[str] = Field(default="") 
    scopes: typing.List[str] = Field(default_factory=list) 
    api_key_id: typing.Optional[str] = Field(default="") 

class Profile(BaseModel):
    user_id: typing.Optional[str] = Field(default="") 
    first_name: typing.Optional[str] = Field(default="") 
    last_name: typing.Optional[str] = Field(default="") 
    company: typing.Optional[str] = Field(default="") 
    role: typing.Optional[str] = Field(default="") 
    timezone: typing.Optional[str] = Field(default="") 
    profile_picture_url: typing.Optional[str] = Field(default="") 
    user_presentation: typing.Optional[str] = Field(default="") 
    targeted_use: typing.Optional[str] = Field(default="") 
    product_updates: typing.Optional[bool] = Field(default=False) 
    phone: typing.Optional[str] = Field(default="") 

class ImpersonateUserRequest(BaseModel):
    _one_of_dict = {"ImpersonateUserRequest.user": {"fields": {"email", "user_id"}}}
    one_of_validator = model_validator(mode="before")(check_one_of)
    user_id: UUID = Field(default="") 
    email: EmailStr = Field(default="") 

class ImpersonateUserResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    token: typing.Optional[str] = Field(default="") 

class ApiKey(BaseModel):
    id: typing.Optional[str] = Field(default="") 
    user_id: typing.Optional[str] = Field(default="") 
    api_key: typing.Optional[str] = Field(default="") 
    name: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 
    created_at: typing.Optional[str] = Field(default="") 

class ApiKeyCreation(BaseModel):
    name: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 

class CreateApiKeyRequest(BaseModel):
    api_key: typing.Optional[ApiKeyCreation] = Field(default=None) 

class CreateApiKeyResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    api_key: typing.Optional[ApiKey] = Field(default=None) 

class ListApiKeysRequest(BaseModel):
    user_id: typing.Optional[str] = Field(default="") 

class ListApiKeysResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    api_keys: typing.List[ApiKey] = Field(default_factory=list) 



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic[v0.2.6.2](https://github.com/so1n/protobuf_to_pydantic)
# Protobuf Version: 5.26.1 
# Pydantic Version: 2.7.1 
from naas_models.pydantic.common_p2p import FieldMask
from naas_models.pydantic.errors_p2p import ErrorResponse
from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic import Field
from uuid import UUID
import typing


class Ontology(BaseModel):
    id: UUID = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    label: typing.Optional[str] = Field(default="") 
    source: typing.Optional[str] = Field(default="") 
    download_url: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 
    logo_url: typing.Optional[str] = Field(default="") 
    level: typing.Optional[str] = Field(default="") 
    is_public: typing.Optional[bool] = Field(default=False) 

class OntologySummary(BaseModel):
    id: UUID = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    label: typing.Optional[str] = Field(default="") 
    download_url: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 
    logo_url: typing.Optional[str] = Field(default="") 
    level: typing.Optional[str] = Field(default="") 
    is_public: typing.Optional[bool] = Field(default=False) 

class OntologyCreation(BaseModel):
    workspace_id: UUID = Field() 
    label: str = Field(min_length=1, max_length=255) 
    source: str = Field(min_length=1) 
    download_url: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 
    logo_url: typing.Optional[str] = Field(default="") 
    level: typing.Optional[str] = Field(default="") 
    is_public: typing.Optional[bool] = Field(default=False) 

class OntologyUpdate(BaseModel):
    id: UUID = Field() 
    workspace_id: typing.Optional[UUID] = Field(default="") 
    label: typing.Optional[str] = Field(default="") 
    source: typing.Optional[str] = Field(default="") 
    download_url: typing.Optional[str] = Field(default="") 
    description: typing.Optional[str] = Field(default="") 
    logo_url: typing.Optional[str] = Field(default="") 
    level: typing.Optional[str] = Field(default="") 
    is_public: typing.Optional[bool] = Field(default=False) 
    field_mask: FieldMask = Field() 

class OntologyListRequest(BaseModel):
    workspace_id: UUID = Field() 
    page_size: int = Field(ge=1, le=100) 
    page_number: int = Field(ge=0) 

class OntologyListResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    ontologies: typing.List[OntologySummary] = Field(default_factory=list) 

class OntologyGetRequest(BaseModel):
    id: UUID = Field(default="") 
    workspace_id: typing.Optional[UUID] = Field(default="") 

class OntologyGetResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    ontology: typing.Optional[Ontology] = Field(default=None) 

class OntologyCreationRequest(BaseModel):
    ontology: OntologyCreation = Field() 

class OntologyCreationResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    ontology: typing.Optional[Ontology] = Field(default=None) 

class OntologyUpdateRequest(BaseModel):
    ontology: OntologyUpdate = Field() 

class OntologyUpdateResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 
    ontology: typing.Optional[Ontology] = Field(default=None) 

class OntologyDeletionRequest(BaseModel):
    id: UUID = Field(default="") 
    workspace_id: UUID = Field(default="") 

class OntologyDeletionResponse(BaseModel):
    error: typing.Optional[ErrorResponse] = Field(default=None) 



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chat.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
import common_pb2 as common__pb2
import naas_models.validate_pb2 as validate__pb2
import errors_pb2 as errors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nchat.proto\x12\x04\x63hat\x1a\x1cgoogle/protobuf/struct.proto\x1a\x0c\x63ommon.proto\x1a\x0evalidate.proto\x1a\x0c\x65rrors.proto\"\xd4\x04\n\x07Message\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12!\n\ncreated_at\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x14\n\x07\x63hat_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x16\n\tfrom_user\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x14\n\x07message\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cmessage_type\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x06\x88\x01\x01\x12\'\n\x10message_language\x18\x08 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x07\x88\x01\x01\x12\x15\n\x08model_id\x18\t \x01(\tH\x08\x88\x01\x01\x12$\n\x04type\x18\n \x01(\x0e\x32\x11.chat.MessageTypeH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x12!\n\ndeleted_at\x18\x0c \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x0b\x88\x01\x01\x12\x15\n\x08selected\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\r\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_versionB\r\n\x0b_created_atB\n\n\x08_chat_idB\x0c\n\n_from_userB\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_model_idB\x07\n\x05_typeB\x0b\n\t_metadataB\r\n\x0b_deleted_atB\x0b\n\t_selectedB\x0e\n\x0c_archived_at\"\xdc\x02\n\rMessageUpdate\x12\x14\n\x07message\x18\x01 \x01(\tH\x00\x88\x01\x01\x12#\n\x0cmessage_type\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x01\x88\x01\x01\x12\'\n\x10message_language\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x15\n\x08metadata\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08selected\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x06 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x05\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x06\x88\x01\x01\x42\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_metadataB\x0b\n\t_selectedB\x0e\n\x0c_archived_atB\r\n\x0b_field_mask\"+\n\x08Messages\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\"R\n\x16MessageDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_version\"N\n\x17MessageDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xef\x01\n\rMessageRating\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12/\n\x06rating\x18\x05 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x04\x88\x01\x01\x42\r\n\x0b_message_idB\n\n\x08_user_idB\x12\n\x10_message_versionB\r\n\x0b_created_atB\t\n\x07_rating\"\xb4\x01\n\x1cMessageRatingCreationRequest\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12/\n\x06rating\x18\x03 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x02\x88\x01\x01\x42\r\n\x0b_message_idB\x12\n\x10_message_versionB\t\n\x07_rating\"\x99\x01\n\x1dMessageRatingCreationResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12\x30\n\x0emessage_rating\x18\x02 \x01(\x0b\x32\x13.chat.MessageRatingH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x11\n\x0f_message_rating\"\xb6\x02\n\x04\x43hat\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x17\n\ncreated_at\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07user_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\ndeleted_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08is_group\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nstarred_at\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\r\n\x0b_created_atB\n\n\x08_user_idB\x07\n\x05_nameB\r\n\x0b_deleted_atB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_at\"\xed\x01\n\nChatUpdate\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08is_group\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x17\n\nstarred_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12*\n\nfield_mask\x18\x64 \x01(\x0b\x32\x11.common.FieldMaskH\x04\x88\x01\x01\x42\x07\n\x05_nameB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_atB\r\n\x0b_field_mask\"\x83\x01\n\x0c\x43hatMessages\x12\x32\n\x08messages\x18\x01 \x03(\x0b\x32 .chat.ChatMessages.MessagesEntry\x1a?\n\rMessagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.chat.Messages:\x02\x38\x01\"o\n\x13\x43hatCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x18\n\x16_is_personal_assistant\"s\n\x14\x43hatCreationResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"(\n\x0e\x43hatGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"n\n\x0f\x43hatGetResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"/\n\x15\x43hatMessageGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x85\x01\n\x16\x43hatMessageGetResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x12)\n\x08messages\x18\x02 \x01(\x0b\x32\x12.chat.ChatMessagesH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_messages\"-\n\x13\x43hatDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\x05\n\x03_id\"K\n\x14\x43hatDeletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"g\n\x11\x43hatUpdateRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12*\n\x0b\x63hat_update\x18\x02 \x01(\x0b\x32\x10.chat.ChatUpdateH\x01\x88\x01\x01\x42\x05\n\x03_idB\x0e\n\x0c_chat_update\"q\n\x12\x43hatUpdateResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"a\n\x0f\x43hatListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"a\n\x10\x43hatListResponse\x12\x18\n\x04\x63hat\x18\x01 \x03(\x0b\x32\n.chat.Chat\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"E\n\x0f\x43hatStarRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04star\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_star\"o\n\x10\x43hatStarResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\",\n\x12\x43hatArchiveRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"J\n\x13\x43hatArchiveResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xa5\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\x12\x19\n\x0cinput_tokens\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12+\n\x06status\x18\x06 \x01(\x0e\x32\x16.chat.CompletionStatusH\x04\x88\x01\x01\x42\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_stepsB\t\n\x07_status\"c\n\x0b\x42\x61sePayload\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prompt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_urlB\t\n\x07_prompt\"\xa5\x01\n\x15\x43hatCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08model_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\tplugin_id\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x03\x88\x01\x01\x42\x05\n\x03_idB\x0b\n\t_model_idB\n\n\x08_payloadB\x0c\n\n_plugin_id\"3\n\x19\x43hatStopCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"Q\n\x1a\x43hatStopCompletionResponse\x12)\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x15.errors.ErrorResponseH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x8f\x01\n\x16\x43hatCompletionResponse\x12\x31\n\ncompletion\x18\x01 \x01(\x0b\x32\x18.chat.CompletionResponseH\x00\x88\x01\x01\x12)\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x15.errors.ErrorResponseH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error*\\\n\x0bMessageType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x06\n\x02\x41I\x10\x02\x12\t\n\x05HUMAN\x10\x03\x12\x0e\n\nTOOL_USAGE\x10\x05\x12\x0f\n\x0bTOOL_ANSWER\x10\x06*:\n\x10\x43ompletionStatus\x12\r\n\tCOMPLETED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02\x32\xfa\x02\n\x0b\x43hatService\x12\x41\n\x06\x43reate\x12\x19.chat.ChatCreationRequest\x1a\x1a.chat.ChatCreationResponse\"\x00\x12\x34\n\x03Get\x12\x14.chat.ChatGetRequest\x1a\x15.chat.ChatGetResponse\"\x00\x12\x37\n\x04List\x12\x15.chat.ChatListRequest\x1a\x16.chat.ChatListResponse\"\x00\x12\x41\n\x06\x44\x65lete\x12\x19.chat.ChatDeletionRequest\x1a\x1a.chat.ChatDeletionResponse\"\x00\x12=\n\x06Update\x12\x17.chat.ChatUpdateRequest\x1a\x18.chat.ChatUpdateResponse\"\x00\x12\x37\n\x04Star\x12\x15.chat.ChatStarRequest\x1a\x16.chat.ChatStarResponse\"\x00\x42-Z+github.com/jupyter-naas/naas-models/go/chatb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'chat_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z+github.com/jupyter-naas/naas-models/go/chat'
  _globals['_MESSAGE'].fields_by_name['created_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['created_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['deleted_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['deleted_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._loaded_options = None
  _globals['_MESSAGEUPDATE'].fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _globals['_MESSAGERATING'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATING'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._loaded_options = None
  _globals['_MESSAGERATINGCREATIONREQUEST'].fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _globals['_CHATMESSAGES_MESSAGESENTRY']._loaded_options = None
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_options = b'8\001'
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._loaded_options = None
  _globals['_CHATCOMPLETIONREQUEST'].fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _globals['_MESSAGETYPE']._serialized_start=4785
  _globals['_MESSAGETYPE']._serialized_end=4877
  _globals['_COMPLETIONSTATUS']._serialized_start=4879
  _globals['_COMPLETIONSTATUS']._serialized_end=4937
  _globals['_MESSAGE']._serialized_start=95
  _globals['_MESSAGE']._serialized_end=691
  _globals['_MESSAGEUPDATE']._serialized_start=694
  _globals['_MESSAGEUPDATE']._serialized_end=1042
  _globals['_MESSAGES']._serialized_start=1044
  _globals['_MESSAGES']._serialized_end=1087
  _globals['_MESSAGEDELETIONREQUEST']._serialized_start=1089
  _globals['_MESSAGEDELETIONREQUEST']._serialized_end=1171
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_start=1173
  _globals['_MESSAGEDELETIONRESPONSE']._serialized_end=1251
  _globals['_MESSAGERATING']._serialized_start=1254
  _globals['_MESSAGERATING']._serialized_end=1493
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_start=1496
  _globals['_MESSAGERATINGCREATIONREQUEST']._serialized_end=1676
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_start=1679
  _globals['_MESSAGERATINGCREATIONRESPONSE']._serialized_end=1832
  _globals['_CHAT']._serialized_start=1835
  _globals['_CHAT']._serialized_end=2145
  _globals['_CHATUPDATE']._serialized_start=2148
  _globals['_CHATUPDATE']._serialized_end=2385
  _globals['_CHATMESSAGES']._serialized_start=2388
  _globals['_CHATMESSAGES']._serialized_end=2519
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_start=2456
  _globals['_CHATMESSAGES_MESSAGESENTRY']._serialized_end=2519
  _globals['_CHATCREATIONREQUEST']._serialized_start=2521
  _globals['_CHATCREATIONREQUEST']._serialized_end=2632
  _globals['_CHATCREATIONRESPONSE']._serialized_start=2634
  _globals['_CHATCREATIONRESPONSE']._serialized_end=2749
  _globals['_CHATGETREQUEST']._serialized_start=2751
  _globals['_CHATGETREQUEST']._serialized_end=2791
  _globals['_CHATGETRESPONSE']._serialized_start=2793
  _globals['_CHATGETRESPONSE']._serialized_end=2903
  _globals['_CHATMESSAGEGETREQUEST']._serialized_start=2905
  _globals['_CHATMESSAGEGETREQUEST']._serialized_end=2952
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_start=2955
  _globals['_CHATMESSAGEGETRESPONSE']._serialized_end=3088
  _globals['_CHATDELETIONREQUEST']._serialized_start=3090
  _globals['_CHATDELETIONREQUEST']._serialized_end=3135
  _globals['_CHATDELETIONRESPONSE']._serialized_start=3137
  _globals['_CHATDELETIONRESPONSE']._serialized_end=3212
  _globals['_CHATUPDATEREQUEST']._serialized_start=3214
  _globals['_CHATUPDATEREQUEST']._serialized_end=3317
  _globals['_CHATUPDATERESPONSE']._serialized_start=3319
  _globals['_CHATUPDATERESPONSE']._serialized_end=3432
  _globals['_CHATLISTREQUEST']._serialized_start=3434
  _globals['_CHATLISTREQUEST']._serialized_end=3531
  _globals['_CHATLISTRESPONSE']._serialized_start=3533
  _globals['_CHATLISTRESPONSE']._serialized_end=3630
  _globals['_CHATSTARREQUEST']._serialized_start=3632
  _globals['_CHATSTARREQUEST']._serialized_end=3701
  _globals['_CHATSTARRESPONSE']._serialized_start=3703
  _globals['_CHATSTARRESPONSE']._serialized_end=3814
  _globals['_CHATARCHIVEREQUEST']._serialized_start=3816
  _globals['_CHATARCHIVEREQUEST']._serialized_end=3860
  _globals['_CHATARCHIVERESPONSE']._serialized_start=3862
  _globals['_CHATARCHIVERESPONSE']._serialized_end=3936
  _globals['_COMPLETIONRESPONSE']._serialized_start=3939
  _globals['_COMPLETIONRESPONSE']._serialized_end=4232
  _globals['_BASEPAYLOAD']._serialized_start=4234
  _globals['_BASEPAYLOAD']._serialized_end=4333
  _globals['_CHATCOMPLETIONREQUEST']._serialized_start=4336
  _globals['_CHATCOMPLETIONREQUEST']._serialized_end=4501
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_start=4503
  _globals['_CHATSTOPCOMPLETIONREQUEST']._serialized_end=4554
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_start=4556
  _globals['_CHATSTOPCOMPLETIONRESPONSE']._serialized_end=4637
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_start=4640
  _globals['_CHATCOMPLETIONRESPONSE']._serialized_end=4783
  _globals['_CHATSERVICE']._serialized_start=4940
  _globals['_CHATSERVICE']._serialized_end=5318
# @@protoc_insertion_point(module_scope)
